# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][],
and this project adheres to [Semantic Versioning][].

[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html

## 0.0.2 (2022-10-03)

### Added

-   Jax Silhouette by @adamgayoso in #1
-   Move silhouette to utils by @adamgayoso in #2
-   Update README.md by @adamgayoso in #3
-   Initial docs by @adamgayoso in #4
-   Silhouette batch + labels by @adamgayoso in #5
-   Add kmeans, nmi, ari metrics by @adamgayoso in #6
-   Isolated labels + settings by @adamgayoso in #7
